GUI Calculator: A calculator written in Python
====================================================================

GUI Calculator is a calculator application written in Python using only the standard library.

The tkinter module is used for the interface, the ast module is used for parsing, testing is done by unittest.